abacusai.vector_store_version — AbacusAI documentation

# `abacusai.vector_store_version`

## Module Contents

### Classes

`VectorStoreVersion` | A version of vector store.

class abacusai.vector_store_version.VectorStoreVersion(client, vectorStoreId=None, vectorStoreVersion=None, createdAt=None, status=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of vector store.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - vectorStoreId (str) – The unique identifier of the vector store.

    - vectorStoreVersion (str) – The unique identifier of the vector store version.

    - createdAt (str) – When the vector store was created.

    - status (str) – The status of creating vector store version.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  wait_for_results(timeout=3600)

    A waiting call until vector store version indexing and deployment is complete.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  wait_until_ready(timeout=3600)

    A waiting call until the vector store version is ready.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the vector store version.

    Returns:

      A string describing the status of a vector store version (pending, complete, etc.).

    Return type:

      str